# Pynacos

#### 介绍
Python环境下的 nacos SDK
于 python 3.7.3环境下编写

#### 安装教程

pip install pynacos

#### 包的依赖
requests

#### 使用说明
具体使用例子请看text.py

nacos 官网
https://nacos.io/zh-cn/

本 SDK 基于 Open-API
https://nacos.io/zh-cn/docs/open-api.html